==> elsfs-sql-0.0.2-sources.jar: org/elsfs/tool/sql/conditions/interfaces/Gt.java <==
package org.elsfs.tool.sql.conditions.interfaces;

/**
 * 大于 >
 *
 * @param <Children> 继承的类型
 * @author zeng
 * @since 0.0.2
 */
public interface Gt<Children> {

  /**
   * 大于
   *
   * @param field 字段名
   * @param value 值
   * @return 具体实现
   */
  default Children gt(String field, Object value) {
    return gt(true, field, value);
  }

  /**
   * 大于
   *
   * @param condition 是否应用条件
   * @param field 字段名
   * @param value 值
   * @return 具体实现
   */
  Children gt(boolean condition, String field, Object value);

  /**
   * 大于
   *
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  default Children gt(Enum<?> field, Object value) {
    return gt(true, field, value);
  }

  /**
   * 大于
   *
   * @param condition 是否应用条件
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  Children gt(boolean condition, Enum<?> field, Object value);

  /**
   * 大于
   *
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  default Children gt(String tableAlias, Enum<?> field, Object value) {
    return gt(true, tableAlias, field, value);
  }

  /**
   * 大于
   *
   * @param condition 是否应用条件
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  Children gt(boolean condition, String tableAlias, Enum<?> field, Object value);

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param field 字段名
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(String field, String sqlValue) {
    return gt(true, field, sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param condition 条件
   * @param field 字段名
   * @param sqlValue sql语句
   * @return 具体实现
   */
  Children gtSql(boolean condition, String field, String sqlValue);

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(Enum<?> field, String sqlValue) {
    return gtSql(true, field, sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param condition 条件
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  Children gtSql(boolean condition, Enum<?> field, String sqlValue);

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(String tableAlias, Enum<?> field, String sqlValue) {
    return gtSql(true, tableAlias, field, sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param condition 条件
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  Children gtSql(boolean condition, String tableAlias, Enum<?> field, String sqlValue);
}

==> elsfs-sql-0.0.3-sources.jar: org/elsfs/tool/sql/conditions/interfaces/Gt.java <==
package org.elsfs.tool.sql.conditions.interfaces;

import org.elsfs.tool.sql.resolve.ResolveFieldName;

/**
 * 大于 >
 *
 * @param <Children> 继承的类型
 * @author zeng
 * @since 0.0.2
 */
public interface Gt<Children> extends ResolveFieldName {

  /**
   * 大于
   *
   * @param field 字段名
   * @param value 值
   * @return 具体实现
   */
  default Children gt(String field, Object value) {
    return gt(true, field, value);
  }

  /**
   * 大于
   *
   * @param condition 是否应用条件
   * @param field 字段名
   * @param value 值
   * @return 具体实现
   */
  Children gt(boolean condition, String field, Object value);

  /**
   * 大于
   *
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  default Children gt(Enum<?> field, Object value) {
    return gt(true, field, value);
  }

  /**
   * 大于
   *
   * @param condition 是否应用条件
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  default Children gt(boolean condition, Enum<?> field, Object value) {
    return gt(condition, resolveFieldName(field), value);
  }

  /**
   * 大于
   *
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  default Children gt(String tableAlias, Enum<?> field, Object value) {
    return gt(true, tableAlias, field, value);
  }

  /**
   * 大于
   *
   * @param condition 是否应用条件
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param value 值
   * @return 具体实现
   */
  default Children gt(boolean condition, String tableAlias, Enum<?> field, Object value) {
    return gt(condition, resolveFieldName(tableAlias, field), value);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param field 字段名
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(String field, String sqlValue) {
    return gt(true, field, sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param condition 条件
   * @param field 字段名
   * @param sqlValue sql语句
   * @return 具体实现
   */
  Children gtSql(boolean condition, String field, String sqlValue);

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(Enum<?> field, String sqlValue) {
    return gtSql(true, field, sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param condition 条件
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(boolean condition, Enum<?> field, String sqlValue) {
    return gtSql(condition, resolveFieldName(field), sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(String tableAlias, Enum<?> field, String sqlValue) {
    return gtSql(true, tableAlias, field, sqlValue);
  }

  /**
   * 字段 &gt; ( sql语句 )
   *
   * <p>例1: gtSql("id", "select id from table where name = 'JunJun'")
   *
   * @param condition 条件
   * @param tableAlias 字段表别名
   * @param field 字段枚举
   * @param sqlValue sql语句
   * @return 具体实现
   */
  default Children gtSql(boolean condition, String tableAlias, Enum<?> field, String sqlValue) {
    return gtSql(condition, resolveFieldName(tableAlias, field), sqlValue);
  }
}
